# script

# stat

# assignment_stat

# varlist1

# var

# var_part

# var_atom

# functioncall

# prefixexp

# name

# keyword

# identifier

# exp_group

# exp

# 'or' operations

# 'and' operations

# <= | < | >= | > | ~= | == operations

# '|' operations

# '~' operations

# '&' operations

# << | >> operations

# '..' operations

# + | - operations

# * | // | / | % operations

# not op operations

# not op

# NOT

# # | - | ~

# '^' operations

# tableconstructor

# LBRACE

# field_list

# field

# fieldsep

# RBRACE

# nested_exp_atom

# NIL

# FALSE

# TRUE

# real number with scientific notation

# real number

# signed integer

# * | // | / | %

# + | -

# << | >>

# <= | < | >= | > | ~= | ==

# AND

# OR

# args

# explist1

# multiline_string

# index_ref

# LBRACK

# RBRACK

# do_stat

# block

# OPT_SEMI

# SEMI

# laststat

# RETURN

# BREAK

# while_stat

# WHILE

# repeat_stat

# REPEAT

# UNTIL

# for_loop_stat

# EQ

# for_seq_stat

# FOR

# namelist

# IN

# DO

# func_call_stat

# if_stat

# IF

# ELSEIF

# THEN

# ELSE

# function_def

# LOCAL

# FUNCTION

# funcname

# COLON

# LPAR

# parlist

# COMMA

# ELLIPSIS

# RPAR

# END